from colorprint.printer import uprint
from colorprint.unicolor import *
def printall():
    printfore()
    printback()

def printmode():
    print("Show Mode:")
    uprint("MODE_NORMAL\n", mode=MODE_NORMAL)
    uprint("MODE_BLINK\n", mode=MODE_BLINK)
    uprint("MODE_BOLD\n", mode=MODE_BOLD)
    uprint("MODE_HIDE\n", mode=MODE_HIDE)
    uprint("MODE_INVERT\n", mode=MODE_INVERT)
    uprint("MODE_UNDERLINE\n", mode=MODE_UNDERLINE)

def printfore():
    print("Show foreground color.")
    uprint("FOREGROUND_BLACK\n", fore=FOREGROUND_BLACK)
    uprint("FOREGROUND_DARKBLUE\n", fore=FOREGROUND_DARKBLUE)
    uprint("FOREGROUND_DARKGREEN\n", fore=FOREGROUND_DARKGREEN)
    uprint("FOREGROUND_DARKSKYBLUE\n", fore=FOREGROUND_DARKSKYBLUE)
    uprint("FOREGROUND_DARKRED\n", fore=FOREGROUND_DARKRED)
    uprint("FOREGROUND_DARKPINK\n", fore=FOREGROUND_DARKPINK)
    uprint("FOREGROUND_DARKYELLOW\n", fore=FOREGROUND_DARKYELLOW)
    uprint("FOREGROUND_DARKWHITE\n", fore=FOREGROUND_DARKWHITE)
    uprint("FOREGROUND_DARKGRAY\n", fore=FOREGROUND_DARKGRAY)
    uprint("FOREGROUND_BLUE\n", fore=FOREGROUND_BLUE)
    uprint("FOREGROUND_GREEN\n", fore=FOREGROUND_GREEN)
    uprint("FOREGROUND_SKYBLUE\n", fore=FOREGROUND_SKYBLUE)
    uprint("FOREGROUND_RED\n", fore=FOREGROUND_RED)
    uprint("FOREGROUND_PINK\n", fore=FOREGROUND_PINK)
    uprint("FOREGROUND_YELLOW\n", fore=FOREGROUND_YELLOW)
    uprint("FOREGROUND_WHITE\n", fore=FOREGROUND_WHITE)

def printback():
    print("Show background color.")
    uprint("BACKGROUND_DARKBLUE\n", back=BACKGROUND_DARKBLUE)
    uprint("BACKGROUND_DARKGREEN\n", back=BACKGROUND_DARKGREEN)
    uprint("BACKGROUND_DARKSKYBLUE\n", back=BACKGROUND_DARKSKYBLUE)
    uprint("BACKGROUND_DARKRED\n", back=BACKGROUND_DARKRED)
    uprint("BACKGROUND_DARKPINK\n", back=BACKGROUND_DARKPINK)
    uprint("BACKGROUND_DARKYELLOW\n", back=BACKGROUND_DARKYELLOW)
    uprint("BACKGROUND_DARKWHITE\n", back=BACKGROUND_DARKWHITE)
    uprint("BACKGROUND_DARKGRAY\n", back=BACKGROUND_DARKGRAY)
    uprint("BACKGROUND_BLUE\n", back=BACKGROUND_BLUE)
    uprint("BACKGROUND_GREEN\n", back=BACKGROUND_GREEN)
    uprint("BACKGROUND_SKYBLUE\n", back=BACKGROUND_SKYBLUE)
    uprint("BACKGROUND_RED\n", back=BACKGROUND_RED)
    uprint("BACKGROUND_PINK\n", back=BACKGROUND_PINK)
    uprint("BACKGROUND_YELLOW\n", back=BACKGROUND_YELLOW)
    uprint("BACKGROUND_WHITE\n", back=BACKGROUND_WHITE)
    uprint("BACKGROUND_WHITE\n", back=BACKGROUND_WHITE)
    uprint("BACKGROUND_WHITE\n", back=BACKGROUND_WHITE)



import ctypes, sys
from colorprint.unicolor import *



if sys.platform == "win32" and sys.stdin.isatty():
    STD_INPUT_HANDLE = -10
    STD_OUTPUT_HANDLE = -11
    STD_ERROR_HANDLE = -12
    std_out_handle = ctypes.windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)
    std_err_handle = ctypes.windll.kernel32.GetStdHandle(STD_ERROR_HANDLE)
    _handle_dict = dict(
        stdout=std_out_handle,
        stderr=std_err_handle
    )
else:
    std_out_handle = sys.stdout
    std_err_handle = sys.stderr
    _handle_dict = dict(
        stdout=sys.stdout,
        stderr=sys.stderr
    )

def set_cmd_text_color(color, handle=std_out_handle):
    Bool = ctypes.windll.kernel32.SetConsoleTextAttribute(handle, color)
    return Bool

def reset_color():
    set_cmd_text_color(FOREGROUND_RED | FOREGROUND_GREEN | FOREGROUND_BLUE)

def in_terminal():
    '''
    在win环境中用python xx.py命令时，只支持获取句柄更改的手段，其他时候，可以用 \033
    :return:
    '''
    return sys.stdin.isatty()
def in_win():
    return sys.platform == "win32"

def cprint(value,fore=None,back=None,end="",handle = "stdout",flush = True):
    '''
    Prints the values to sys.stdout or sys.stderr.
    :param color:look the document or unicolor.py
        Foreground color and Background color can use 'or' operating
    :param end:
    :param handle: string, use "stdout" or "stderr", default "stdout"
    :param flush: default True, if False, the color will be the final color you set.
    :return:
    '''
    if fore is None and back is None:
        reset_color()
    elif back is None:
        set_cmd_text_color(fore)
    elif fore is None:
        set_cmd_text_color(back)
    else:
        set_cmd_text_color(fore|back)



    sys.stdout.write(str(value))

    if flush:
        sys.stdout.flush()

    reset_color()
    return cprint

def eprint(value,fore=None,back = None,mode = None,end="",handle = "stdout",flush = True):
    if mode is None:
        mode = MODE_NORMAL
    if fore is None and back is None:
        print(f"\033[{mode}m{value}\033[0m", end=end, file=_handle_dict[handle], flush=flush)
    elif back is None:
        print(f"\033[{mode};{fore}m{value}\033[0m", end = end, file=_handle_dict[handle], flush=flush)
    elif fore is None:
        print(f"\033[{mode};;{back}m{value}\033[0m",end = end,file=_handle_dict[handle],flush=flush)
    else:
        print(f"\033[{mode};{fore};{back}m{value}\033[0m", end=end, file=_handle_dict[handle], flush=flush)




def uprint(value,fore=None,back = None,mode = None,end="",handle = "stdout",flush = True):
    if in_win() and in_terminal():
        cprint(value=value, fore=fore, back=back, end=end, handle=handle, flush=flush)
    else:
        eprint(value=value,fore=fore,back=back,mode=mode,end=end,handle=handle,flush=flush)

    return uprint


from setuptools import setup,find_packages

setup(
    name='sailist',
    version='0.3.1.dev1',
    description='convert markdown 2 latex code perfactly,support Chinese Language',
    url='https://github.com/sailist/colorprint',
    author='sailist',
    author_email='sailist@outlook.com',
    license='MIT',
    include_package_data = True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    keywords='colored text print terminal',
    packages=find_packages(),
)